@@ -3,11 +3,11 @@ build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
- 'ALIGNOF_LONG': 4,
- 'ALIGNOF_SIZE_T': 4,
+ 'ALIGNOF_LONG': 8,
+ 'ALIGNOF_SIZE_T': 8,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
- 'AR': 'ar',
+ 'AR': '/usr/bin/ar',
  'ARFLAGS': 'rcs',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code',
  'BASECPPFLAGS': '',
@@ -15,21 +15,21 @@ build_time_vars = {'ABIFLAGS': '',
  'BINDIR': '/usr/local/bin',
  'BINLIBDEST': '/usr/local/lib/python3.10',
  'BLDLIBRARY': '-L. -lpython3.10',
- 'BLDSHARED': 'cc -pthread -shared -fPIC',
+ 'BLDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'powerpc-unknown-openbsd7.1',
+ 'BUILD_GNU_TYPE': 'x86_64-unknown-openbsd7.2',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG -O2 '
-           '-pipe   -fPIC -O2 -pipe -O2 -pipe',
+           '-pipe -g  -fPIC -O2 -pipe -g -O2 -pipe -g',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -pipe',
- 'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
+ 'CONFIGURE_CFLAGS': '-O2 -pipe -g',
+ 'CONFIGURE_CFLAGS_NODIST': '-flto -g -std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
@@ -37,23 +37,27 @@ build_time_vars = {'ABIFLAGS': '',
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/local/include',
  'CONFIGURE_LDFLAGS': '-L/usr/local/lib/',
- 'CONFIGURE_LDFLAGS_NODIST': '',
+ 'CONFIGURE_LDFLAGS_NODIST': '-flto -g',
  'CONFIG_ARGS': "'--enable-shared' '--with-fpectl' '--with-threads' "
                 "'--enable-ipv6' '--with-system-expat' '--with-system-ffi' "
-                "'--enable-loadable-sqlite-extensions' '--prefix=/usr/local' "
+                "'--with-tcltk-includes=-I/usr/local/include/tcl8.6 "
+                "-I/usr/local/include/tk8.6 -I/usr/X11R6/include' "
+                "'--with-tcltk-libs=-L/usr/X11R6/lib -ltcl86 -ltk86' "
+                "'--enable-loadable-sqlite-extensions' '--with-lto' "
+                "'--enable-optimizations' '--prefix=/usr/local' "
                 "'--sysconfdir=/etc' '--mandir=/usr/local/man' "
                 "'--infodir=/usr/local/info' '--localstatedir=/var' "
                 "'--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' "
-                "'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' "
+                "'CFLAGS=-O2 -pipe -g' 'LDFLAGS=-L/usr/local/lib/' "
                 "'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/usr/obj/ports/Python-3.10.4/Python-3.10.4/coverage.info',
- 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.10.4/Python-3.10.4/lcov-report',
+ 'COVERAGE_INFO': '/usr/obj/ports/Python-3.10.7/Python-3.10.7/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.10.7/Python-3.10.7/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
- 'CPPFLAGS': '-I. -I./Include',
+ 'CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'CXX': 'c++ -pthread',
  'DESTDIRS': '/usr/local /usr/local/lib /usr/local/lib/python3.10 '
              '/usr/local/lib/python3.10/lib-dynload',
@@ -70,8 +74,8 @@ build_time_vars = {'ABIFLAGS': '',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 1,
- 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 0,
+ 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
+ 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
  'DTRACE': '',
  'DTRACE_DEPS': '\\',
  'DTRACE_HEADERS': '',
@@ -88,7 +92,7 @@ build_time_vars = {'ABIFLAGS': '',
  'EXTRA_CFLAGS': '',
  'EXT_SUFFIX': '.cpython-310.so',
  'FILEMODE': 644,
- 'FLOAT_WORDS_BIGENDIAN': 1,
+ 'FLOAT_WORDS_BIGENDIAN': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
  'GITBRANCH': '',
@@ -155,7 +159,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_DECL_RTLD_LOCAL': 1,
  'HAVE_DECL_RTLD_MEMBER': 0,
  'HAVE_DECL_RTLD_NODELETE': 1,
- 'HAVE_DECL_RTLD_NOLOAD': 0,
+ 'HAVE_DECL_RTLD_NOLOAD': 1,
  'HAVE_DECL_RTLD_NOW': 1,
  'HAVE_DECL_TZNAME': 0,
  'HAVE_DEVICE_MACROS': 1,
@@ -213,9 +217,9 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GAMMA': 1,
  'HAVE_GCC_ASM_FOR_MC68881': 0,
- 'HAVE_GCC_ASM_FOR_X64': 0,
- 'HAVE_GCC_ASM_FOR_X87': 0,
- 'HAVE_GCC_UINT128_T': 0,
+ 'HAVE_GCC_ASM_FOR_X64': 1,
+ 'HAVE_GCC_ASM_FOR_X87': 1,
+ 'HAVE_GCC_UINT128_T': 1,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETENTROPY': 1,
@@ -266,7 +270,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 1,
+ 'HAVE_LARGEFILE_SUPPORT': 0,
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
@@ -524,25 +528,25 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'powerpc-unknown-openbsd7.1',
+ 'HOST_GNU_TYPE': 'x86_64-unknown-openbsd7.2',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
                    '/usr/local/include/python3.10 '
                    '/usr/local/include/python3.10',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python3.10',
- 'INSTALL': '/usr/obj/ports/Python-3.10.4/bin/install -c',
- 'INSTALL_DATA': '/usr/obj/ports/Python-3.10.4/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.10.4/bin/install -c -s -m 755',
- 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.10.4/bin/install -c -m 755',
- 'INSTALL_SHARED': '/usr/obj/ports/Python-3.10.4/bin/install -c -m 755',
+ 'INSTALL': '/usr/obj/ports/Python-3.10.7/bin/install -c',
+ 'INSTALL_DATA': '/usr/obj/ports/Python-3.10.7/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.10.7/bin/install -c  -m 755',
+ 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.10.7/bin/install -c -m 755',
+ 'INSTALL_SHARED': '/usr/obj/ports/Python-3.10.7/bin/install -c -m 755',
  'INSTSONAME': 'libpython3.10.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared -fPIC',
- 'LDFLAGS': '',
+ 'LDFLAGS': '-L/usr/local/lib/',
  'LDLIBRARY': 'libpython3.10.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'cc -pthread -shared -fPIC',
+ 'LDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/',
  'LDVERSION': '3.10',
  'LIBC': '',
  'LIBDEST': '/usr/local/lib/python3.10',
@@ -565,8 +569,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
- 'LLVM_PROF_FILE': '',
- 'LLVM_PROF_MERGER': '',
+ 'LLVM_PROF_FILE': 'LLVM_PROFILE_FILE="code-%p.profclangr"',
+ 'LLVM_PROF_MERGER': '/usr/bin/llvm-profdata merge -output=code.profclangd '
+                     '*.profclangr',
  'LN': 'ln',
  'LOCALMODLIBS': '',
  'MACHDEP': 'openbsd7',
@@ -607,7 +612,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
- 'OPT': '-DNDEBUG -O2 -pipe   -fPIC',
+ 'OPT': '-DNDEBUG -O2 -pipe -g  -fPIC',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -619,8 +624,8 @@ build_time_vars = {'ABIFLAGS': '',
  'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/tokenizer.o',
  'PEGEN_HEADERS': '\\',
  'PEGEN_OBJS': '\\',
- 'PGO_PROF_GEN_FLAG': '',
- 'PGO_PROF_USE_FLAG': '',
+ 'PGO_PROF_GEN_FLAG': '-fprofile-instr-generate',
+ 'PGO_PROF_USE_FLAG': '-fprofile-instr-use=code.profclangd',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
@@ -642,49 +647,55 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                             '-Wunreachable-code -DNDEBUG -O2 -pipe   -fPIC '
-                             '-O2 -pipe -O2 -pipe -std=c99 -Wextra '
-                             '-Wno-unused-result -Wno-unused-parameter '
+                             '-Wunreachable-code -DNDEBUG -O2 -pipe -g  -fPIC '
+                             '-O2 -pipe -g -O2 -pipe -g -flto -g -std=c99 '
+                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden -I/usr/local/include '
-                             '-I./Include/internal -I. -I./Include -fPIC '
+                             '-fprofile-instr-use=code.profclangd '
+                             '-I./Include/internal -I. -I./Include '
+                             '-I/usr/local/include -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG '
-              '-O2 -pipe   -fPIC -O2 -pipe -O2 -pipe',
- 'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
+              '-O2 -pipe -g  -fPIC -O2 -pipe -g -O2 -pipe -g',
+ 'PY_CFLAGS_NODIST': '-flto -g -std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden -I/usr/local/include '
-                     '-I./Include/internal',
+                     '-fprofile-instr-use=code.profclangd -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
-                   '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -std=c99 '
-                   '-Wextra -Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wstrict-prototypes '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden '
-                   '-I/usr/local/include -I./Include/internal -I. -I./Include '
-                   '-fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L/usr/obj/ports/Python-3.10.4/Python-3.10.4 '
+                   '-DNDEBUG -O2 -pipe -g  -fPIC -O2 -pipe -g -O2 -pipe -g '
+                   '-flto -g -std=c99 -Wextra -Wno-unused-result '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                   '-fvisibility=hidden -I/usr/local/include '
+                   '-fprofile-instr-use=code.profclangd -I./Include/internal '
+                   '-I. -I./Include -I/usr/local/include -fPIC -DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-L/usr/local/lib/ -flto -g '
+                    '-L/usr/obj/ports/Python-3.10.7/Python-3.10.7 '
                     '-L/usr/local/lib/',
- 'PY_CPPFLAGS': '-I. -I./Include',
+ 'PY_CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '',
- 'PY_LDFLAGS_NODIST': '-L/usr/obj/ports/Python-3.10.4/Python-3.10.4 '
+ 'PY_LDFLAGS': '-L/usr/local/lib/',
+ 'PY_LDFLAGS_NODIST': '-flto -g -L/usr/obj/ports/Python-3.10.7/Python-3.10.7 '
                       '-L/usr/local/lib/',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
-                        '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe '
-                        '-std=c99 -Wextra -Wno-unused-result '
+                        '-DNDEBUG -O2 -pipe -g  -fPIC -O2 -pipe -g -O2 -pipe '
+                        '-g -flto -g -std=c99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden -I/usr/local/include '
-                        '-I./Include/internal -I. -I./Include -fPIC',
+                        '-fprofile-instr-use=code.profclangd '
+                        '-I./Include/internal -I. -I./Include '
+                        '-I/usr/local/include -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -693,7 +704,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.10.4/Python-3.10.4',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.10.7/Python-3.10.7',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SHELL': '/bin/sh',
@@ -706,18 +717,18 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 8,
+ 'SIZEOF_LONG': 8,
+ 'SIZEOF_LONG_DOUBLE': 16,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
  'SIZEOF_PTHREAD_KEY_T': 4,
- 'SIZEOF_PTHREAD_T': 4,
+ 'SIZEOF_PTHREAD_T': 8,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 4,
+ 'SIZEOF_SIZE_T': 8,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 4,
- 'SIZEOF_VOID_P': 4,
+ 'SIZEOF_UINTPTR_T': 8,
+ 'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-310',
@@ -731,14 +742,15 @@ build_time_vars = {'ABIFLAGS': '',
  'SUBDIRSTOO': 'Include Lib Misc',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
- 'TCLTK_INCLUDES': '',
- 'TCLTK_LIBS': '',
+ 'TCLTK_INCLUDES': '-I/usr/local/include/tcl8.6 -I/usr/local/include/tk8.6 '
+                   '-I/usr/X11R6/include',
+ 'TCLTK_LIBS': '-L/usr/X11R6/lib -ltcl86 -ltk86',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.10.4/Python-3.10.4 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.10.7/Python-3.10.7 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.10.4/Python-3.10.4 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.10.7/Python-3.10.7 '
                './python ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -766,8 +778,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/ports/Python-3.10.4/Python-3.10.4',
- 'abs_srcdir': '/usr/obj/ports/Python-3.10.4/Python-3.10.4',
+ 'abs_builddir': '/usr/obj/ports/Python-3.10.7/Python-3.10.7',
+ 'abs_srcdir': '/usr/obj/ports/Python-3.10.7/Python-3.10.7',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
